from djangosuggestions import fields
from django.db.models import CharField
from django.utils.translation import ugettext, ugettext_lazy as _


class SuggestionField(CharField):

    description = _("text field with suggestions")
    suggestions = ()

    def __init__(self, suggestions=(), *args, **kwargs):
        self.suggestions = suggestions
        super(SuggestionField, self).__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        defaults = {
            'form_class': fields.SuggestionField,
            'suggestions': self.suggestions,
        }
        defaults.update(kwargs)
        return super(SuggestionField, self).formfield(**defaults)

    def south_field_triple(self):
        from south.modelsinspector import introspector
        args, kwargs = introspector(self)
        return ('djangosuggestions.models.SuggestionField', args, kwargs)




from django import forms
from djangosuggestions.widgets import SuggestionWidget


class SuggestionField(forms.CharField):

    widget = SuggestionWidget

    def __init__(self, suggestions=(), *args, **kwargs):
        super(SuggestionField, self).__init__(*args, **kwargs)
        self.suggestions = suggestions

    def _get_suggestions(self):
        return self._suggestions

    def _set_suggestions(self, suggestions):
        self._suggestions = suggestions
        self.widget.suggestions = suggestions

    suggestions = property(_get_suggestions, _set_suggestions)



#!/usr/bin/env python
"""
Install django-suggestions using setuptools
"""

from djangosuggestions import __version__

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

setup(
    name='django-suggestions',
    version=__version__,
    description='A Django form widget that implements the HTML5 form list element',
    author='Tim Heap',
    author_email='tim@timheap.me',
    url='https://bitbucket.org/tim_heap/django-suggestions',

    packages=find_packages(),

    package_data={},
    include_package_data=True,

    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
)



from django.forms.utils import flatatt
from django.forms.widgets import TextInput
from django.utils.html import conditional_escape, format_html, format_html_join
from django.utils.translation import ugettext, ugettext_lazy as _
from django.utils.encoding import force_text, python_2_unicode_compatible
from django.utils.safestring import mark_safe
from itertools import chain


class SuggestionWidget(TextInput):

    def __init__(self, suggestions=(), *args, **kwargs):
        super(SuggestionWidget, self).__init__(*args, **kwargs)
        self.suggestions = list(suggestions)

    def render(self, name, value, attrs=None, suggestions=()):
        attrs = attrs or {}
        has_id = attrs and 'id' in attrs
        final_attrs = self.build_attrs(attrs, name=name)

        if has_id:
            list_id = attrs['id'] + '__list'
            options = (format_html('<option>{0}</option>', suggestion)
                       for suggestion in chain(self.suggestions, suggestions))

            attrs['list'] = list_id
            datalist = '<datalist{attrs}><select>{options}</select></datalist>'.format(
                attrs=flatatt({'id': list_id}),
                options=''.join(options))
        else:
            datalist = ''

        out = super(SuggestionWidget, self).render(name, value, attrs)
        return mark_safe(out + datalist)
